@@ -9,7 +9,7 @@ allows better process control, which reduces the chance of system overload.
 More importantly, if you intend to use inetd Bucktooth on a system that times
 inetd processes out if sockets remain open, you will be running a very
 unstable server without alarm() support. (This is only an issue with inetd
-Bucktooth, not xinetd Bucktooths.)
+Bucktooth, not xinetd or launchd-based Bucktooths.)
 
 You can still install Bucktooth, but consider running this on a system that
 supports alarm() in its Perl port.
@@ -31,8 +31,9 @@ unless you're darn certain that they'll all be configured the same way.
 IF YOU'RE USING CONFIGURE TO BUILD MULTIPLE INSTANCES OF Bucktooth ON MULTIPLE
 IP ADDRESSES (xinetd only), THIS *MUST* BE DIFFERENT IN EACH CASE!
 
-WARNING TO xinetd/inetd INSTALLERS: If you are doing a full install to update
-(x)inetd's config files simultaneously, THIS MUST BE AN ABSOLUTE PATH!
+WARNING TO xinetd/inetd/launchd INSTALLERS: If you are doing a full install
+to update (x)inetd/launchd's config files simultaneously, THIS MUST BE AN
+ABSOLUTE PATH!
 
 Install path?
 EOF
@@ -84,7 +85,9 @@ EOF
 $PORT_NO = &prompt(<<"EOF", "70", 1);
 What numerical TCP port do you want the server to run on? 70 is the default
 but if you're using configure to build multiple Bucktooths on multiple ports,
-make sure you give a different answer this time.
+make sure you give a different answer this time. This number is built into
+the server, so you must have different built executables for different ports,
+and an executable for every port you plan to use.
 
 If you're not doing a full install, this just tells the server what port it
 will be on, and doesn't actually change any configuration files.
@@ -169,7 +172,7 @@ EOF
 if ($DEF_MCANALARM) {
 	$q = &prompt(<<"EOF", "n", 1);
 Now the ugly kludge section. This is really only relevant to inetd users, but
-this option may be occasionally useful to xinetd installs.
+this option may be occasionally useful to xinetd or launchd installs.
 
 Some inetds will time out, and then shut down, services that hold sockets
 open for longer than a critical period of time (Linux inetd is the most
